@@ -37,6 +37,7 @@
 	    reify-declr reify-decl
 	    def-namer
 	    split-udecl
+	    declr-ident declr-name
 	    clean-field-list clean-fields)
   #:use-module (nyacc lang sx-util)
   #:use-module (srfi srfi-11)		; let-values
@@ -50,6 +51,30 @@
 (define (pperr exp)
   (pretty-print exp (current-error-port) #:per-line-prefix "  "))
 
+;; @deffn {Procedure} declr-ident declr => (ident "name")
+;; Given a declarator, aka @code{init-declr}, return the identifier.
+;; This is used by @code{trans-unit->udict}.
+;; @end deffn
+(define (declr-ident declr)
+  (sx-match declr
+    ((ident ,name) declr)
+    ((init-declr ,declr . ,rest) (declr-ident declr))
+    ((comp-declr ,declr) (declr-ident declr))
+    ((param-declr ,declr) (declr-ident declr))
+    ((ary-declr ,dir-declr ,array-spec) (declr-ident dir-declr))
+    ((ary-declr ,dir-declr) (declr-ident dir-declr))
+    ((ptr-declr ,pointer ,dir-declr) (declr-ident dir-declr))
+    ((ftn-declr ,dir-declr . ,rest) (declr-ident dir-declr))
+    ((scope ,declr) (declr-ident declr))
+    ((bit-field ,ident . ,rest) ident)
+    (,_ (throw 'c99-error "c99/munge: unknown declarator: ~S" declr))))
+
+;; @deffn {Procedure} declr-name declr => "name"
+;; This extracts the name from the return value of @code{declr-ident}.
+;; @end deffn
+(define (declr-name declr)
+  (and=> (declr-ident declr) cadr))
+
 ;; @deffn {Procedure} declr-list? declr
 ;; Determine if declr it is a list or not.
 ;; Often declr can be xxxx-declr-list or xxxx-declr.
@@ -441,6 +466,7 @@
 ;; been munged into udecls.  The behavior is actually NOT DEFINED.
 ;; @end deffn
 (define* (expand-typerefs adecl udict #:optional (keep '()))
+  ;; TODO: replace typeof() with type
 
   ;; In the process of expanding typerefs it is crutial that routines which
   ;; expand parts return the original if no change made.  That is, if there
@@ -572,6 +598,12 @@
 
   (probe-declr declr))
 
+;; @deffn {Procedure} reify-decl decl [#:namer proc]
+;; This procedure turns an abstract declaration into a concrete one,
+;; using the optional namer, a procedure that generates a string name.
+;; The default namer is "_", but this may not work in contexts where
+;; multiple distinct names are required.
+;; @end deffn
 (define* (reify-decl udecl #:optional (namer def-namer))
   (call-with-values
       (lambda () (split-udecl udecl))
